@@ -1,11 +1,12 @@
-#' @import ggplot2
-#' @importFrom grDevices dev.new dev.interactive
-#' @importFrom utils head write.table
-#' @export
+###' @import ggplot2
+###' @importFrom grDevices dev.new dev.interactive
+###' @importFrom utils head write.table
+###' @export
 plot.TextData <- function (x, ndoc=25, nword=25, nseg=25, sel=NULL,
   stop.word.tm=FALSE, stop.word.user=NULL, theme=theme_bw(), title=NULL, xtitle=NULL,
-  col.fill="grey", col.lines="black", text.size=12, ...)
+  col.fill="grey", col.lines="black", text.size=12, freq=NULL, vline=NULL,...)
 {
+  
 if (!inherits(x, "TextData")) 
  stop("Object x should be TextData class")
 
@@ -13,6 +14,8 @@ idiom <- x$info$idiom[[1]]
 theme$text$size <- text.size
 words<-iFreq<-docnames<-rsegment<-frequency<-NULL
 
+if(!is.null(freq)) if(freq=="YES"| freq==TRUE) freq <- 5
+
 if(!is.null(sel)) {
 if(sel=="seg") {ndoc<-0; nword<-0} 
 if(sel=="word") {ndoc<-0; nseg<-0}
@@ -36,11 +39,14 @@ df <- data.frame(x$indexS$segOrderFreq[,])
 
  pseg <- ggplot(df)+ geom_bar(aes(x=rsegment, y=frequency),stat = "identity", color = col.lines, fill = col.fill) + coord_flip() +
  ylab(txtitle) + xlab("") + ggtitle(ttitle) + theme + theme(plot.title = element_text(hjust = 0.5))
-if (dev.interactive()) dev.new()
- print(pseg)
+ if(!is.null(freq))
+      pseg <- pseg+ geom_text(aes(x=rsegment, y=frequency+ freq, label = frequency))
+ if (dev.interactive()) dev.new() 
+  print(pseg)
 }}
 
 
+
 df <- data.frame(x$indexW[,1], rownames(x$indexW))
 colnames(df) <- c("iFreq", "words") 
 
@@ -59,6 +65,11 @@ if(nword>0){
 ifelse(is.null(title), ttitle <- paste0( nword," most frequent words"), ttitle <- title)
 ifelse(is.null(xtitle), txtitle <- "Word frequency", txtitle <- xtitle)
 
+vlineword <- NULL
+if(!is.null(vline)) {
+  if(is.numeric(vline)) vlineword <- vline
+  if(vline=="YES"|vline==TRUE ) vlineword <- mean(df$iFreq)
+  if(vline=="median") vlineword <- median(df$iFreq)}
 # Present the results ordered by frequency
  df <- df[with(df, order(-iFreq,words)), ]
  df <- df[c(1:nword),]
@@ -66,8 +77,19 @@ ifelse(is.null(xtitle), txtitle <- "Word frequency", txtitle <- xtitle)
  df$words <- reorder(df$words,-as.numeric(rownames(df)))
  pword <- ggplot(df)+ geom_bar(aes(x=words, y=iFreq),stat = "identity", color = col.lines, fill = col.fill)+ coord_flip() +
 ylab(txtitle) + xlab("") + ggtitle(ttitle) + theme + theme(plot.title = element_text(hjust = 0.5))
-if (dev.interactive()) dev.new()
-print(pword)
+ if(!is.null(freq))
+   pword <- pword+ geom_text(aes(x=df$words, y=iFreq+ freq, label = iFreq))
+
+
+ if(!is.null(vlineword)) {
+   pword <- pword+ geom_hline(yintercept=vlineword, linetype="dashed", color = "red")
+ }
+ 
+ 
+ 
+ 
+  if (dev.interactive()) dev.new()
+  print(pword)
 }
 
 
@@ -78,6 +100,13 @@ docnames <- rownames(x$DocTerm)
 colnames(DT) <- c("i","j","v")
 iFreq <- sapply(split(DT, DT$i), function(z) sum(z$v))
 df <- data.frame(docnames, iFreq)
+
+if(!is.null(vline)) {
+  if(is.numeric(vline)) vlinedoc <- vline
+  if(vline=="YES"|vline==TRUE ) vlinedoc <- mean(df$iFreq)
+  if(vline=="median") vlinedoc <- median(df$iFreq)}
+
+
 # Presents the results ordered by frequency
 df <- df[with(df, order(-iFreq,docnames)), ]
 ndoc <- min(ndoc, nrow(df))
@@ -88,6 +117,13 @@ ifelse(is.null(xtitle), txtitle <- "Document length", txtitle <- xtitle)
 df$docnames <- reorder(df$docnames,df$iFreq)
 pdoc <-ggplot2::ggplot(df)+ geom_bar(aes(x=docnames, y=iFreq),stat = "identity", color = col.lines, fill = col.fill)+ coord_flip() +
   ylab(txtitle) + xlab("") + ggtitle(ttitle) + theme + theme(plot.title = element_text(hjust = 0.5))
+if(!is.null(freq))
+  pdoc <- pdoc+ geom_text(aes(x=docnames, y=iFreq+ freq, label = iFreq))
+
+ if(!is.null(vline)) {
+   pdoc <- pdoc+ geom_hline(yintercept=vlinedoc, linetype="dashed", color = "red")
+}
+
 if (dev.interactive()) dev.new()
 print(pdoc)
 }
